@@ -36,14 +36,20 @@ class DownloadDirTestCase(TestCase):
         request = factory.get("/download-dir/")
         self.assertNotIn('path', request.GET)
 
-        user_storage.listdir.return_value = ([], [{"name": "file1", "data-product-uri": "dp1"},
-                                                  {"name": "file2", "data-product-uri": "dp2"},
-                                                  {"name": "file3", "data-product-uri": "dp3"}])
+        file1_content = b''
+        file2_content = b'file2 content'
+        file3_content = b'file3 content'
+        user_storage.listdir.return_value = (
+            [],
+            [{"name": "file1", "data-product-uri": "dp1", "size": len(file1_content)},
+             {"name": "file2", "data-product-uri": "dp2", "size": len(file2_content)},
+             {"name": "file3", "data-product-uri": "dp3", "size": len(file3_content)}]
+        )
 
         user_storage.open_file.side_effect = self._mock_open_file({
-            "dp1": ("file1", b''),
-            "dp2": ("file2", b'file2 content'),
-            "dp3": ("file3", b'file3 content'),
+            "dp1": ("file1", file1_content),
+            "dp2": ("file2", file2_content),
+            "dp3": ("file3", file3_content),
         })
 
         response = views.download_dir(request)
@@ -55,9 +61,9 @@ class DownloadDirTestCase(TestCase):
         self.assertEqual("application/zip", response['Content-Type'])
         zf = zipfile.ZipFile(io.BytesIO(response.getvalue()))
         self.assertSequenceEqual(["file1", "file2", "file3"], zf.namelist())
-        self.assertEqual(b'', zf.read("file1"))
-        self.assertEqual(b'file2 content', zf.read("file2"))
-        self.assertEqual(b'file3 content', zf.read("file3"))
+        self.assertEqual(file1_content, zf.read("file1"))
+        self.assertEqual(file2_content, zf.read("file2"))
+        self.assertEqual(file3_content, zf.read("file3"))
 
     @ patch("airavata_django_portal_sdk.views.user_storage")
     def test_download_dir_files_and_subdirectories(self, user_storage):
@@ -68,20 +74,20 @@ class DownloadDirTestCase(TestCase):
 
         def listdir(request, path, *args, **kwargs):
             if path == "":
-                return [{"name": "dir1"}, {"name": "dir2"}], [{"name": "file1", "data-product-uri": "dp"},
-                                                              {"name": "file2", "data-product-uri": "dp"},
-                                                              {"name": "file3", "data-product-uri": "dp"}]
+                return [{"name": "dir1"}, {"name": "dir2"}], [{"name": "file1", "data-product-uri": "dp", "size": 0},
+                                                              {"name": "file2", "data-product-uri": "dp", "size": 0},
+                                                              {"name": "file3", "data-product-uri": "dp", "size": 0}]
             if path == "dir1":
-                return [{"name": "dir3"}], [{"name": "dir1file1", "data-product-uri": "dp"},
-                                            {"name": "dir1file2", "data-product-uri": "dp"}]
+                return [{"name": "dir3"}], [{"name": "dir1file1", "data-product-uri": "dp", "size": 0},
+                                            {"name": "dir1file2", "data-product-uri": "dp", "size": 0}]
             elif path == "dir2":
-                return [{"name": "dir4"}], [{"name": "dir2file1", "data-product-uri": "dp"},
-                                            {"name": "dir2file2", "data-product-uri": "dp"}]
+                return [{"name": "dir4"}], [{"name": "dir2file1", "data-product-uri": "dp", "size": 0},
+                                            {"name": "dir2file2", "data-product-uri": "dp", "size": 0}]
             elif path == "dir1/dir3":
                 # empty dir
                 return [], []
             elif path == "dir2/dir4":
-                return [], [{"name": "dir4file1", "data-product-uri": "dp"}]
+                return [], [{"name": "dir4file1", "data-product-uri": "dp", "size": 0}]
         user_storage.listdir.side_effect = listdir
         user_storage.open_file.side_effect = self._mock_open_file({"dp": ('file', b'')})
 
